/******************************************************************************
 JXSRDialogUpdateTask.h

	Interface for the JXSRDialogUpdateTask class

	Copyright © 1996 by John Lindal. All rights reserved.

 ******************************************************************************/

#ifndef _H_JXSRDialogUpdateTask
#define _H_JXSRDialogUpdateTask

#include <JXIdleTask.h>

class JXSRTextDialogBase;

class JXSRDialogUpdateTask : public JXIdleTask
{
public:

	JXSRDialogUpdateTask(JXSRTextDialogBase* dialog);

	virtual ~JXSRDialogUpdateTask();

	virtual void	Perform(const Time delta, Time* maxSleepTime);

private:

	JXSRTextDialogBase*	itsDialog;	// this owns us

private:

	// not allowed

	JXSRDialogUpdateTask(const JXSRDialogUpdateTask& source);
	const JXSRDialogUpdateTask& operator=(const JXSRDialogUpdateTask& source);
};

#endif
