/******************************************************************************
 JXRegexHelpText.h.h

	Copyright © 1997 by John Lindal. All rights reserved.

 ******************************************************************************/

#ifndef _H_JXRegexHelpText
#define _H_JXRegexHelpText

#include <jTypes.h>

extern const JCharacter* kRegexHelpName;
extern const JCharacter* kRegexHelpTitle;
extern const JCharacter* kRegexHelpText;

extern const JCharacter* kRegexQRefName;
extern const JCharacter* kRegexQRefTitle;
extern const JCharacter* kRegexQRefText;

#endif