/******************************************************************************
 JXSRFullDialog.h

	Interface for the JXSRFullDialog class

	Copyright © 1996 by John Lindal. All rights reserved.

 ******************************************************************************/

#ifndef _H_JXSRFullDialog
#define _H_JXSRFullDialog

#include <JXSRTextDialogBase.h>

class JXTextButton;
class JXInputField;
class JXTextCheckbox;
class JXRadioGroup;
class JXStringHistoryMenu;

class JXSRFullDialog : public JXSRTextDialogBase
{
public:

	JXSRFullDialog(JXDirector* supervisor);

	virtual ~JXSRFullDialog();

protected:

private:

// begin JXLayout

    JXRadioGroup*        itsSearchRG;
    JXTextButton*        itsCloseButton;
    JXTextButton*        itsFindButton;
    JXTextCheckbox*      itsIgnoreCaseCB;
    JXTextCheckbox*      itsWrapSearchCB;
    JXTextButton*        itsReplaceButton;
    JXTextButton*        itsReplaceAllButton;
    JXTextButton*        itsReplaceFindButton;
    JXTextCheckbox*      itsEntireWordCB;
    JXStringHistoryMenu* itsPrevReplaceMenu;
    JXStringHistoryMenu* itsPrevSearchMenu;
    JXInputField*	     itsSearchInput;
    JXInputField*        itsReplaceInput;
    JXTextButton*        itsHelpButton;
    JXTextCheckbox*      itsSearchIsRegexCB;
    JXTextCheckbox*      itsReplaceIsRegexCB;
    JXTextCheckbox*      itsSingleLineCB;
    JXTextCheckbox*      itsPreserveCaseCB;
    JXTextButton*        itsQRefButton;

// end JXLayout

private:

	void	BuildWindow();

	// not allowed

	JXSRFullDialog(const JXSRFullDialog& source);
	const JXSRFullDialog& operator=(const JXSRFullDialog& source);
};

#endif
